Module error

Module error 

Errors raised when scoring inputs or learned parameters violate their contract.

Enums

ScoringError
A scoring request could not be evaluated without producing an invalid score.

Type Aliases

ScoringResult