pub struct EvidenceLogit(/* private fields */);Expand description
Signed prior-free log-likelihood-ratio evidence.
Zero is neutral. Positive values support relevance and negative values oppose it.
Implementations
Sourceimpl EvidenceLogit
impl EvidenceLogit
pub fn new(value: f64) -> ScoringResult<Self>
Sourcepub fn from_prior_free_probability(probability: f64) -> ScoringResult<Self>
pub fn from_prior_free_probability(probability: f64) -> ScoringResult<Self>
Convert a prior-free probability-like evidence value into logit space.
Calling this method is an explicit assertion that probability does
not already contain a relevance prior.
pub const fn neutral() -> Self
pub const fn value(self) -> f64